==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiGui/QDesktopServices_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtGui/qdesktopservices.h>
#include <QtCore/QVariant>
#include <QtCore/qurl.h>
#include <QtCore/qobject.h>
#include <QtCore/qstandardpaths.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDesktopServices(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDesktopServices")
    QDesktopServices *_ptr = reinterpret_cast<QDesktopServices *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QDesktopServices_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QDesktopServices *__qt_this = new(__qtjambi_ptr) QDesktopServices();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QDesktopServices
void __qt_destruct_QDesktopServices(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDesktopServices")
    reinterpret_cast<QDesktopServices*>(ptr)->~QDesktopServices();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDesktopServices::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QDesktopServices_initialize_1native__Lio_qt_gui_QDesktopServices_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDesktopServices::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDesktopServices_0, sizeof(QDesktopServices), typeid(QDesktopServices), false, &deleter_QDesktopServices, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDesktopServices::openUrl(QUrl)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QDesktopServices_openUrl_1native_1cref_1QUrl__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID url0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDesktopServices::openUrl(QUrl)")
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QUrl& __qt_url0 = QtJambiAPI::valueReferenceFromNativeId<QUrl>(url0);
        __java_return_value = QDesktopServices::openUrl(__qt_url0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDesktopServices::setUrlHandler(QString,QObject*,const char*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QDesktopServices_setUrlHandler_1native_1cref_1QString_1QObject_1ptr_1const_1char_1ptr__Ljava_lang_String_2J)
(JNIEnv *__jni_env,
 jclass,
 jstring scheme0,
 QtJambiNativeID receiver1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDesktopServices::setUrlHandler(QString,QObject*,const char*)")
    QTJAMBI_TRY {
        QString  __qt_scheme0 = qtjambi_cast<QString >(__jni_env, scheme0);
        QObject* __qt_receiver1 = QtJambiAPI::objectFromNativeId<QObject>(receiver1);
        const char* __qt_method2 = "handleUrl";
        QDesktopServices::setUrlHandler(__qt_scheme0, __qt_receiver1, __qt_method2);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDesktopServices::unsetUrlHandler(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QDesktopServices_unsetUrlHandler_1native_1cref_1QString__Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass,
 jstring scheme0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDesktopServices::unsetUrlHandler(QString)")
    QTJAMBI_TRY {
        QString  __qt_scheme0 = qtjambi_cast<QString >(__jni_env, scheme0);
        QDesktopServices::unsetUrlHandler(__qt_scheme0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QDesktopServices(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QDesktopServices>("QDesktopServices", "io/qt/gui/QDesktopServices");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QDesktopServices, {
        ConstructorInfo(&__qt_construct_QDesktopServices_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDesktopServices);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiGui/QDesktopServices_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtGui/qdesktopservices.h>
#include <QtCore/QVariant>
#include <QtCore/qobject.h>
#include <QtCore/qurl.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDesktopServices(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDesktopServices")
    QDesktopServices *_ptr = reinterpret_cast<QDesktopServices *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QDesktopServices()
void __qt_construct_QDesktopServices(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDesktopServices()")
    Q_UNUSED(__java_arguments)
    QDesktopServices *__qt_this = new(__qtjambi_ptr) QDesktopServices();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QDesktopServices::QDesktopServices()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QDesktopServices_initialize_1native__Lio_qt_gui_QDesktopServices_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDesktopServices::QDesktopServices()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDesktopServices, sizeof(QDesktopServices), typeid(QDesktopServices), 0, false, &deleter_QDesktopServices, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QDesktopServices
void __qt_destruct_QDesktopServices(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDesktopServices")
    reinterpret_cast<QDesktopServices*>(ptr)->~QDesktopServices();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDesktopServices::openUrl(QUrl)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QDesktopServices_openUrl_1native_1cref_1QUrl__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID url0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDesktopServices::openUrl(QUrl)")
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QUrl& __qt_url0 = QtJambiAPI::valueReferenceFromNativeId<QUrl>(url0);
        __java_return_value = QDesktopServices::openUrl(__qt_url0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDesktopServices::setUrlHandler(QString,QObject*,const char*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QDesktopServices_setUrlHandler_1native_1cref_1QString_1QObject_1ptr_1const_1char_1ptr__Ljava_lang_String_2J)
(JNIEnv *__jni_env,
 jclass,
 jstring scheme0,
 QtJambiNativeID receiver1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDesktopServices::setUrlHandler(QString,QObject*,const char*)")
    QTJAMBI_TRY {
        QString  __qt_scheme0 = qtjambi_cast<QString>(__jni_env, scheme0);
        QObject* __qt_receiver1 = QtJambiAPI::objectFromNativeId<QObject>(receiver1);
        const char* __qt_method2 = "handleUrl";
        QDesktopServices::setUrlHandler(__qt_scheme0, __qt_receiver1, __qt_method2);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDesktopServices::unsetUrlHandler(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QDesktopServices_unsetUrlHandler_1native_1cref_1QString__Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass,
 jstring scheme0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDesktopServices::unsetUrlHandler(QString)")
    QTJAMBI_TRY {
        QString  __qt_scheme0 = qtjambi_cast<QString>(__jni_env, scheme0);
        QDesktopServices::unsetUrlHandler(__qt_scheme0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QDesktopServices(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QDesktopServices>("QDesktopServices", "io/qt/gui/QDesktopServices");
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QDesktopServices, {
        ConstructorInfo(&__qt_construct_QDesktopServices, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDesktopServices);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
